
# This file was automatically generated by Dist::Zilla::Plugin::ModuleBuild v5.042.
use strict;
use warnings;

use Module::Build 0.28;


my %module_build_args = (
  "build_requires" => {
    "Module::Build" => "0.28"
  },
  "configure_requires" => {
    "ExtUtils::MakeMaker" => 0,
    "Module::Build" => "0.28",
    "perl" => "5.008001"
  },
  "dist_abstract" => "Easy, versatile, portable file handling",
  "dist_author" => [
    "Tommy Butler"
  ],
  "dist_name" => "File-Util",
  "dist_version" => "4.161950",
  "license" => "perl",
  "module_name" => "File::Util",
  "recommends" => {
    "Unicode::UTF8" => "0.58"
  },
  "recursive_test_files" => 1,
  "requires" => {
    "Exporter" => 0,
    "Fcntl" => 0,
    "Scalar::Util" => 0,
    "constant" => 0,
    "lib" => 0,
    "perl" => "5.008001",
    "strict" => 0,
    "subs" => 0,
    "vars" => 0,
    "warnings" => 0
  },
  "test_requires" => {
    "AutoLoader" => 0,
    "Config" => 0,
    "Cwd" => 0,
    "Exporter" => 0,
    "ExtUtils::MakeMaker" => 0,
    "Fcntl" => 0,
    "File::Spec" => 0,
    "File::Temp" => 0,
    "IO::Handle" => 0,
    "IPC::Open3" => 0,
    "Module::Build" => "0.28",
    "Scalar::Util" => 0,
    "Test" => 0,
    "Test::More" => 0,
    "Test::NoWarnings" => 0,
    "blib" => "1.01",
    "perl" => "5.008001",
    "utf8" => 0
  }
);


my %fallback_build_requires = (
  "AutoLoader" => 0,
  "Config" => 0,
  "Cwd" => 0,
  "Exporter" => 0,
  "ExtUtils::MakeMaker" => 0,
  "Fcntl" => 0,
  "File::Spec" => 0,
  "File::Temp" => 0,
  "IO::Handle" => 0,
  "IPC::Open3" => 0,
  "Module::Build" => "0.28",
  "Scalar::Util" => 0,
  "Test" => 0,
  "Test::More" => 0,
  "Test::NoWarnings" => 0,
  "blib" => "1.01",
  "perl" => "5.008001",
  "utf8" => 0
);


unless ( eval { Module::Build->VERSION(0.4004) } ) {
  delete $module_build_args{test_requires};
  $module_build_args{build_requires} = \%fallback_build_requires;
}

my $build = Module::Build->new(%module_build_args);


$build->create_build_script;
