use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007000
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib  ) );
__DATA__
AND'ed
ascii
bitmask
BrowserUk
BLOCKEX
CIFS
conf
dat
dbitmask
ebcdic
EBCDIC
EPOC
failsafe
FIFOs
Github
html
inodes
listrefs
NFS
oct
onfail
SIGNES
SL
SMB
Solaris
SOLARIS
subpattern
subref
subrefs
syntaxes
trunc
txt
unicode
VMS
vtab
benchmarking
merchantability
lexically
cpan
CPAN
filename
filenames
metadata
namespace
OO
POSIX
pre
STDERR
subclasses
subdirectories
subdirectory
UTF
shiftjis
iso
Tommy
Butler
John
Fields
jfields
Ricardo
rjbs
Matt
Trout
perl
Nicholas
Perez
nperez
David
Golden
dagolden
lib
File
Util
Cookbook
Definitions
Exception
Diagnostic
Standard
Interface
Classic
Modern
Manual
Examples
