severity = 5
verbose = 8

[Variables::ProhibitPunctuationVars]
allow = $@ $!

[TestingAndDebugging::ProhibitNoStrict]
allow = refs

# Turn these off
[-BuiltinFunctions::ProhibitStringyEval]

# Turn this on
[Lax::ProhibitStringyEval::ExceptForRequire]
